pub struct Args {Show 18 fields
pub help: bool,
pub version: bool,
pub all: bool,
pub color: TriBool,
pub ascii: bool,
pub remote_stats: TriBool,
pub list_cols: bool,
pub cols: Cols,
pub filter: Option<Filter>,
pub sort: Sorting,
pub units: Units,
pub json: bool,
pub csv: bool,
pub csv_separator: char,
pub strategy: Option<String>,
pub timeout: Option<Timeout>,
pub bar_width: usize,
pub path: Option<PathBuf>,
}Expand description
List your filesystems.
Documentation at https://dystroy.org/dysk
Fields
help: boolprint help information
version: boolprint the version
all: boolshow all mount points
color: TriBoolwhether to have styles and colors
ascii: booluse only ASCII characters for table rendering
remote_stats: TriBoolfetch stats of remote volumes
list_cols: boollist the column names which can be used in -s, -f, or -c
cols: Colscolumns, eg -c +inodes or -c id+dev+default
filter: Option<Filter>filter, eg -f '(size<35G | remote=false) & type=xfs'
sort: Sortingsort, eg inodes, type-desc, or size-asc
units: Unitsunits: SI (SI norm), binary (1024 based), or bytes (raw number)
json: booloutput as JSON
csv: booloutput as CSV
csv_separator: charCSV separator
strategy: Option<String>strategy to use to find information, when several are available
timeout: Option<Timeout>timeout to use for some operations, eg 10s or 5ms
bar_width: usizewidth of the progress bar in the ‘use’ and ‘inodes’ columns
path: Option<PathBuf>if provided, only the device holding this path will be shown
Implementations